# Generated by Django 4.1.9 on 2023-06-28 13:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wbportfolio", "0040_instrument_financial_instrument"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="listresearch",
            name="research_ptr",
        ),
        migrations.RemoveField(
            model_name="onetextboxresearch",
            name="research_ptr",
        ),
        migrations.RemoveField(
            model_name="optionlistresearchtopic",
            name="researchtopic_ptr",
        ),
        migrations.RemoveField(
            model_name="outlookresearch",
            name="research_ptr",
        ),
        migrations.RemoveField(
            model_name="porterfiveresearch",
            name="research_ptr",
        ),
        migrations.RemoveField(
            model_name="referenceresearch",
            name="list_research",
        ),
        migrations.RemoveField(
            model_name="relationshipresearch",
            name="entry",
        ),
        migrations.RemoveField(
            model_name="relationshipresearch",
            name="list_research",
        ),
        migrations.AlterUniqueTogether(
            name="research",
            unique_together=None,
        ),
        migrations.RemoveField(
            model_name="research",
            name="content_type",
        ),
        migrations.RemoveField(
            model_name="research",
            name="research_topic",
        ),
        migrations.RemoveField(
            model_name="researchtemplate",
            name="content_type",
        ),
        migrations.RemoveField(
            model_name="researchtopic",
            name="group",
        ),
        migrations.RemoveField(
            model_name="researchtopicrelationship",
            name="content_type",
        ),
        migrations.RemoveField(
            model_name="researchtopicrelationship",
            name="topic",
        ),
        migrations.RemoveField(
            model_name="swotresearch",
            name="research_ptr",
        ),
        migrations.RemoveField(
            model_name="timelineresearch",
            name="list_research",
        ),
        migrations.RemoveField(
            model_name="twotextboxresearch",
            name="research_ptr",
        ),
        migrations.DeleteModel(
            name="ListElementResearch",
        ),
        migrations.DeleteModel(
            name="ListResearch",
        ),
        migrations.DeleteModel(
            name="OneTextBoxResearch",
        ),
        migrations.DeleteModel(
            name="OptionListResearchTopic",
        ),
        migrations.DeleteModel(
            name="OutlookResearch",
        ),
        migrations.DeleteModel(
            name="PorterFiveResearch",
        ),
        migrations.DeleteModel(
            name="ReferenceResearch",
        ),
        migrations.DeleteModel(
            name="RelationshipResearch",
        ),
        migrations.DeleteModel(
            name="Research",
        ),
        migrations.DeleteModel(
            name="ResearchTemplate",
        ),
        migrations.DeleteModel(
            name="ResearchTopic",
        ),
        migrations.DeleteModel(
            name="ResearchTopicRelationship",
        ),
        migrations.DeleteModel(
            name="SWOTResearch",
        ),
        migrations.DeleteModel(
            name="TimelineResearch",
        ),
        migrations.DeleteModel(
            name="TwoTextBoxResearch",
        ),
    ]
