# Generated by Django 4.2.9 on 2024-02-16 08:33

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wbportfolio", "0055_remove_product__custom_management_rebates_and_more"),
    ]

    operations = [
        migrations.SeparateDatabaseAndState(
            state_operations=[
                migrations.RemoveField(
                    model_name="companyportfoliodata",
                    name="assets_under_management_currency",
                ),
                migrations.RemoveField(
                    model_name="companyportfoliodata",
                    name="company",
                ),
                migrations.RemoveField(
                    model_name="companyportfoliodata",
                    name="potential_currency",
                ),
                migrations.RemoveField(
                    model_name="geographicfocus",
                    name="company",
                ),
                migrations.RemoveField(
                    model_name="geographicfocus",
                    name="country",
                ),
                migrations.DeleteModel(
                    name="AssetAllocation",
                ),
                migrations.DeleteModel(
                    name="AssetAllocationType",
                ),
                migrations.DeleteModel(
                    name="CompanyPortfolioData",
                ),
                migrations.DeleteModel(
                    name="GeographicFocus",
                ),
            ],
            database_operations=[
                migrations.AlterModelTable(name="AssetAllocation", table="company_portfolio_assetallocation"),
                migrations.AlterModelTable(name="AssetAllocationType", table="company_portfolio_assetallocationtype"),
                migrations.AlterModelTable(
                    name="CompanyPortfolioData", table="company_portfolio_companyportfoliodata"
                ),
                migrations.AlterModelTable(name="GeographicFocus", table="company_portfolio_geographicfocus"),
            ],
        )
    ]
